@@ -5,3 +5,5 @@ from .ninjax import scope
 from .ninjax import Module
 from .ninjax import grad
 from .ninjax import HaikuModule
+from .ninjax import FlaxModule
+from .ninjax import OptaxModule
